/****************************************************************************/
/*                                                                          */
/*  Functions:  Input strings; print them and their reversed images.        */
/*              Place the digits of an integer into a character array,      */
/*              that prints the same as the original number.                */
/*                                                                          */
/*  Author:   Bary W Pollack                                                */
/*                                                                          */
/*  File:     Arrays.cpp                                                    */
/*                                                                          */
/*  Date:     11/12/97      Revised:                                        */
/*                                                                          */
/*  Input:    A sequence of strings, bounded by whitespace.                 */
/*            The sentinel is leading period.                               */
/*            Then, a sequence of integers, bounded by whitespace, and a .  */
/*                                                                          */
/****************************************************************************/

#include <iostream.h>
#include <string.h>
#include <math.h>

/****************************************************************************/

int main (void)
{
    void ReverseAString (void);
    void IntegerToString (void);

    ReverseAString ();
    IntegerToString ();
    return 0;
} // end main

/****************************************************************************/
/*  ReverseAString reads strings and reverses them until it sees a dot.     */
/****************************************************************************/

void ReverseAString (void)
{
    const char cSENTINEL = '.';
    const int  nMAX_LTH = 40;
    char  sInputString [nMAX_LTH], sOutputString [nMAX_LTH];

    do
    {
        cin >> sInputString;
        int nLength = strlen (sInputString);
        for (int nIndex = 0; nIndex < nLength; nIndex++)
            sOutputString [nLength-1-nIndex] = sInputString [nIndex];
        sOutputString [nLength] = '\0';
        cout << "Input:  " << sInputString << endl
             << "Output: " << sOutputString << endl
             << endl;
    } while (sInputString [0] != cSENTINEL);
} // end ReverseAString

/****************************************************************************/
/*  IntegerToString converts an integer into its C++ string equivalent      */
/*  (The output is the same as the  itoa()  library function.)              */
/****************************************************************************/

void IntegerToString (void)
{
    const int   nMAX_DIGITS = 7;
    char  sDigits [nMAX_DIGITS];
    int   nNumber;
    int   NumberOfDigits (int nNumber);

    do
    {
        cin >> nNumber;
        if (cin.fail ())
            break;

        nNumber = abs (nNumber);
        int nIndex = NumberOfDigits (nNumber);
        sDigits [nIndex--] = '\0';
        int nWorkNumber = nNumber;
        while (nWorkNumber != 0)
        {
            sDigits [nIndex--] = (char) ((nWorkNumber % 10) + '0');
            nWorkNumber /= 10;
        }
        cout << "nNumber = " << nNumber << " = '" << sDigits << "'" << endl;
    } while (nNumber > 0);
} // end IntegerToString

/****************************************************************************/
/*  NumberOfDigits tells how many digits are in a number > 0.               */
/*  (You could use the  log10()  math library function to do this...)       */
/****************************************************************************/

int NumberOfDigits (int nNumber)
{
    nNumber = abs (nNumber);
    return ((nNumber >= 10000) ? 5 :
            (nNumber >= 1000)  ? 4 :
            (nNumber >= 100)   ? 3 :
            (nNumber >= 10)    ? 2 : 1);
} // end NumberOfDigits

/****************************************************************************

A is the BEST character because it's first .
Input:  A
Output: A

Input:  is
Output: si

Input:  the
Output: eht

Input:  BEST
Output: TSEB

Input:  character
Output: retcarahc

Input:  because
Output: esuaceb

Input:  it's
Output: s'ti

Input:  first
Output: tsrif

Input:  .
Output: .


9 87 654 3210 12345 .
nNumber = 9 = '9'
nNumber = 87 = '87'
nNumber = 654 = '654'
nNumber = 3210 = '3210'
nNumber = 12345 = '12345'                            */
